==> thunderbird_78.8.0.orig.tar.xz: thunderbird-78.8.0/security/manager/ssl/tests/unit/test_pkcs11_safe_mode.js <==
/* -*- indent-tabs-mode: nil; js-indent-level: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
"use strict";

// In safe mode, PKCS#11 modules should not be loaded. This test tests this by
// simulating starting in safe mode and then attempting to load a module.

function run_test() {
  do_get_profile();

  // Simulate starting in safe mode.
  let xulRuntime = {
    inSafeMode: true,
    logConsoleErrors: true,
    OS: "XPCShell",
    XPCOMABI: "noarch-spidermonkey",
    invalidateCachesOnRestart: function invalidateCachesOnRestart() {
      // Do nothing
    },
    QueryInterface: ChromeUtils.generateQI([Ci.nsIXULRuntime]),
  };

  let xulRuntimeFactory = {
    createInstance(outer, iid) {
      if (outer != null) {
        throw Components.Exception("", Cr.NS_ERROR_NO_AGGREGATION);
      }
      return xulRuntime.QueryInterface(iid);
    },
  };

  let registrar = Components.manager.QueryInterface(Ci.nsIComponentRegistrar);
  const XULRUNTIME_CONTRACTID = "@mozilla.org/xre/runtime;1";
  const XULRUNTIME_CID = Components.ID(
    "{f0f0b230-5525-4127-98dc-7bca39059e70}"
  );
  registrar.registerFactory(
    XULRUNTIME_CID,
    "XULRuntime",
    XULRUNTIME_CONTRACTID,
    xulRuntimeFactory
  );

  // When starting in safe mode, the test module should fail to load.
  let pkcs11ModuleDB = Cc["@mozilla.org/security/pkcs11moduledb;1"].getService(
    Ci.nsIPKCS11ModuleDB
  );
  let libraryName = ctypes.libraryName("pkcs11testmodule");
  let libraryFile = Services.dirsvc.get("CurWorkD", Ci.nsIFile);
  libraryFile.append("pkcs11testmodule");
  libraryFile.append(libraryName);
  ok(libraryFile.exists(), "The pkcs11testmodule file should exist");
  throws(
    () =>
      pkcs11ModuleDB.addModule("PKCS11 Test Module", libraryFile.path, 0, 0),
    /NS_ERROR_FAILURE/,
    "addModule should throw when in safe mode"
  );
}

==> thunderbird_91.12.0.orig.tar.xz: thunderbird-91.12.0/security/manager/ssl/tests/unit/test_pkcs11_safe_mode.js <==
/* -*- indent-tabs-mode: nil; js-indent-level: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
"use strict";

// In safe mode, PKCS#11 modules should not be loaded. This test tests this by
// simulating starting in safe mode and then attempting to load a module.

function run_test() {
  do_get_profile();

  // Simulate starting in safe mode.
  let xulRuntime = {
    inSafeMode: true,
    logConsoleErrors: true,
    OS: "XPCShell",
    XPCOMABI: "noarch-spidermonkey",
    invalidateCachesOnRestart: function invalidateCachesOnRestart() {
      // Do nothing
    },
    QueryInterface: ChromeUtils.generateQI(["nsIXULRuntime"]),
  };

  let xulRuntimeFactory = {
    createInstance(outer, iid) {
      if (outer != null) {
        throw Components.Exception("", Cr.NS_ERROR_NO_AGGREGATION);
      }
      return xulRuntime.QueryInterface(iid);
    },
  };

  let registrar = Components.manager.QueryInterface(Ci.nsIComponentRegistrar);
  const XULRUNTIME_CONTRACTID = "@mozilla.org/xre/runtime;1";
  const XULRUNTIME_CID = Components.ID(
    "{f0f0b230-5525-4127-98dc-7bca39059e70}"
  );
  registrar.registerFactory(
    XULRUNTIME_CID,
    "XULRuntime",
    XULRUNTIME_CONTRACTID,
    xulRuntimeFactory
  );

  // When starting in safe mode, the test module should fail to load.
  let pkcs11ModuleDB = Cc["@mozilla.org/security/pkcs11moduledb;1"].getService(
    Ci.nsIPKCS11ModuleDB
  );
  let libraryName = ctypes.libraryName("pkcs11testmodule");
  let libraryFile = Services.dirsvc.get("CurWorkD", Ci.nsIFile);
  libraryFile.append("pkcs11testmodule");
  libraryFile.append(libraryName);
  ok(libraryFile.exists(), "The pkcs11testmodule file should exist");
  throws(
    () =>
      pkcs11ModuleDB.addModule("PKCS11 Test Module", libraryFile.path, 0, 0),
    /NS_ERROR_FAILURE/,
    "addModule should throw when in safe mode"
  );
}
